@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2022-12-06 18:11:52
+:LastEditTime: 2022-12-07 18:53:09
 :LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
@@ -464,8 +464,7 @@ class StudioBaseHandler(BaseCookieHandler):
                 self.clear_cookie("UserID")
                 self.clear_cookie("UserIDMD5")
                 self.clear_cookie("UserToken")
-                # return self.response_common("UserExpire", "用户已过期，请重新登录")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已过期，请重新登录"
                 return invoke_result
             if user_login["UserToken"] != user_token:
@@ -474,15 +473,13 @@ class StudioBaseHandler(BaseCookieHandler):
                 self.clear_cookie("UserID")
                 self.clear_cookie("UserIDMD5")
                 self.clear_cookie("UserToken")
-                # return self.response_common("DeviceExpire", "用户在其他终端登录，请重新登录")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                 return invoke_result
 
             curr_user_info = UserInfoModel(config.get_value("manage_context_key")).get_entity_by_id(user_id)
             if curr_user_info.IsLock == 1:
-                # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                 return invoke_result
 
@@ -498,8 +495,7 @@ class StudioBaseHandler(BaseCookieHandler):
                 self.clear_cookie("UserID")
                 self.clear_cookie("UserIDMD5")
                 self.clear_cookie("UserToken")
-                # return self.response_common("UserExpire", "用户已过期，请重新登录")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已过期，请重新登录"
                 return invoke_result
             if user_login.UserToken != user_token:
@@ -508,8 +504,7 @@ class StudioBaseHandler(BaseCookieHandler):
                 self.clear_cookie("UserID")
                 self.clear_cookie("UserIDMD5")
                 self.clear_cookie("UserToken")
-                # return self.response_common("DeviceExpire", "用户在其他终端登录，请重新登录")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                 return invoke_result
 
@@ -517,26 +512,22 @@ class StudioBaseHandler(BaseCookieHandler):
 
             curr_user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
             if not curr_user_info:
-                # return self.response_common("UserNoExist", "用户不存在，请重新登录")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已过期，请重新登录"
                 return invoke_result
             if curr_user_info.IsLock == 1:
-                # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
-                invoke_result.ResultCode = "error"
+                invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                 return invoke_result
 
             if base_manage_context_key != manage_context_key:
                 curr_user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
                 if not curr_user_info:
-                    # return self.response_common("UserNoExist", "用户不存在，请重新登录")
-                    invoke_result.ResultCode = "error"
+                    invoke_result.ResultCode = "login_expire"
                     invoke_result.ResultMessage = "用户已过期，请重新登录"
                     return invoke_result
                 if curr_user_info.IsLock == 1:
-                    # return self.response_common("UserLimit", "用户已被锁，请联系管理员")
-                    invoke_result.ResultCode = "error"
+                    invoke_result.ResultCode = "login_expire"
                     invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                     return invoke_result
 
@@ -556,13 +547,12 @@ class StudioBaseHandler(BaseCookieHandler):
         user_info = self.get_curr_user_info()
         base_user_info = self.get_base_user_info()
         if not user_info or not base_user_info:
-            invoke_result.ResultCode = "error"
+            invoke_result.ResultCode = "login_expire"
             invoke_result.ResultMessage = "用户已过期，请重新登录"
             return invoke_result
         if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
             api_path = self.request.path
             if api_path.strip() == "":
-                # return self.response_common("NoPower", "没有权限")
                 invoke_result.ResultCode = "error"
                 invoke_result.ResultMessage = "该用户没有权限，请联系管理员"
                 return invoke_result
