@@ -1,7 +1,7 @@
 """
 :Author: wang kui
 :Date: 2020-03-24 16:32:52
-:LastEditTime: 2021-06-29 18:38:33
+:LastEditTime: 2022-12-06 09:52:36
 :LastEditors: HuangJingCan
 :Description: power 用户权限相关接口
 """
@@ -42,7 +42,7 @@ class GetUserInfoHandler(StudioBaseHandler):
             curr_info["Email"] = user_info.Email
             curr_info["PersonalitySignature"] = user_info.PersonalitySignature
 
-        self.reponse_json_success(curr_info)
+        return self.response_json_success(curr_info)
 
 
 class GetUserProductListHandler(StudioBaseHandler):
@@ -83,12 +83,12 @@ class GetUserProductListHandler(StudioBaseHandler):
                 condition = f"IsRelease=1 AND ProductID IN({list_str})"
                 product_infos = product_info_model.get_list(condition)
             elif not product_data:
-                return self.reponse_common("NoData", "没有其他平台权限")
+                return self.response_common("NoData", "没有其他平台权限")
 
         for product_info in product_infos:
             product_data.append(self.__to_user_product_data(user_id, product_info, is_super))
 
-        self.reponse_json_success(product_data)
+        return self.response_json_success(product_data)
 
     def __to_user_product_data(self, user_id, product_info, is_super):
         """
@@ -169,7 +169,7 @@ class FocusPasswordHandler(StudioBaseHandler):
             invoke_result.ResultCode = "Has Change Password"
             invoke_result.ResultMessage = "密码已修改过"
 
-        self.reponse_custom(invoke_result)
+        return self.response_custom(invoke_result)
 
 
 class FocusChangeUserPwHandler(StudioBaseHandler):
@@ -195,13 +195,13 @@ class FocusChangeUserPwHandler(StudioBaseHandler):
 
         is_force_password = user_info_ex.is_force_password(base_user_info)
         if not is_force_password:
-            return self.reponse_common("Error", "无需强制更改密码")
+            return self.response_common("Error", "无需强制更改密码")
         sign_password = user_info_ex.sign_password(password, user_id)
         user_info_model_ex.update_table(f"Password=%s", "UserID=%s", [sign_password, user_id])
 
         self.logout(user_id)
 
-        self.reponse_custom(invoke_result)
+        return self.response_custom(invoke_result)
 
 
 class ChangeCurrUserPwHandler(StudioBaseHandler):
@@ -226,13 +226,13 @@ class ChangeCurrUserPwHandler(StudioBaseHandler):
             user_id = base_user_info.UserID
 
         if not user_info_model_ex.verify_password(password, base_user_info.Password, user_id):
-            return self.reponse_common("ErrorPassword", "旧密码错误，请重新输入")
+            return self.response_common("ErrorPassword", "旧密码错误，请重新输入")
         sign_password = user_info_model_ex.sign_password(new_password, user_id)
         user_info_model_ex.update_table(f"Password=%s", "UserID=%s", [sign_password, user_id])
 
         self.logout(user_id)
 
-        self.reponse_custom(invoke_result)
+        return self.response_custom(invoke_result)
 
 
 class GetRoleListHandler(StudioBaseHandler):
@@ -257,7 +257,7 @@ class GetRoleListHandler(StudioBaseHandler):
 
         role_dict_list = RoleInfoModel(manage_context_key).get_dict_list(condition, field="RoleID,RoleName")
 
-        self.reponse_json_success(role_dict_list)
+        return self.response_json_success(role_dict_list)
 
 
 class GetRoleUserListHandler(StudioBaseHandler):
@@ -291,7 +291,7 @@ class GetRoleUserListHandler(StudioBaseHandler):
 
         page_list, total = role_info_model.get_page_list("*", page_index, page_size, condition, "", order)
         if not page_list:
-            return self.reponse_json_success(page_data)
+            return self.response_json_success(page_data)
 
         user_ids_list = [i.ModifyUserID for i in page_list]
         user_ids_str = str(user_ids_list).strip('[').strip(']')
@@ -319,7 +319,7 @@ class GetRoleUserListHandler(StudioBaseHandler):
         page_data.PageSize = page_size
         page_data.PageIndex = page_index
 
-        self.reponse_json_success(page_data)
+        return self.response_json_success(page_data)
 
 
 class GetUserRoleListHandler(StudioBaseHandler):
@@ -353,7 +353,7 @@ class GetUserRoleListHandler(StudioBaseHandler):
 
         page_list, total = user_info_model.get_page_list("*", page_index, page_size, condition, "", order)
         if not page_list:
-            return self.reponse_json_success(page_data)
+            return self.response_json_success(page_data)
 
         chief_user_ids_list = [i.ChiefUserID for i in page_list]
         chief_user_ids_str = str(chief_user_ids_list).strip('[').strip(']')
@@ -383,7 +383,7 @@ class GetUserRoleListHandler(StudioBaseHandler):
         page_data.PageSize = page_size
         page_data.PageIndex = page_index
 
-        self.reponse_json_success(page_data)
+        return self.response_json_success(page_data)
 
 
 class SaveUserHandler(StudioBaseHandler):
@@ -419,21 +419,21 @@ class SaveUserHandler(StudioBaseHandler):
 
         # 验证数据
         if account == "":
-            return self.reponse_common("AccountEmpty", "账号为空")
+            return self.response_common("AccountEmpty", "账号为空")
 
         user_info_model = UserInfoModel(self.get_manage_context_key())
         user_info = UserInfo()
         if user_id != "":
             user_info = user_info_model.get_entity_by_id(user_id)
             if not user_info:
-                return self.reponse_common("NoExit", "用户不存在")
+                return self.response_common("NoExit", "用户不存在")
             user_info_c = user_info_model.get_entity("Account=%s AND UserID!=%s", params=[account, user_id])
             if user_info_c:
-                return self.reponse_common("Exit", "账号已存在")
+                return self.response_common("Exit", "账号已存在")
         else:
             user_info_c = user_info_model.get_entity("Account=%s", params=account)
             if user_info_c:
-                return self.reponse_common("Exit", "账号已存在")
+                return self.response_common("Exit", "账号已存在")
 
         user_info.Account = account
         user_info.Email = email
@@ -449,7 +449,7 @@ class SaveUserHandler(StudioBaseHandler):
         is_add = user_id == ""
         result = power_model.set_user(user_info, user_role_id_str.split(","), user_product_id_str.split(","), password, change_pw, is_add)
 
-        self.reponse_json_success(result)
+        return self.response_json_success(result)
 
 
 class SaveCurrUserHandler(StudioBaseHandler):
@@ -475,7 +475,7 @@ class SaveCurrUserHandler(StudioBaseHandler):
         user_info_model = UserInfoModel(self.get_manage_context_key())
         user_info = user_info_model.get_entity_by_id(user_id)
         if user_id == "" or not user_info:
-            return self.reponse_common("Exit", "账号不存在")
+            return self.response_common("Exit", "账号不存在")
 
         user_info.Email = email
         user_info.NickName = nick_name
@@ -485,7 +485,7 @@ class SaveCurrUserHandler(StudioBaseHandler):
 
         user_info_model.update_entity(user_info, field_list=["Email", "NickName", "Phone", "Avatar", "PersonalitySignature"])
 
-        self.reponse_json_success(user_info)
+        return self.response_json_success(user_info)
 
 
 class GetUserListHandler(StudioBaseHandler):
@@ -510,7 +510,7 @@ class GetUserListHandler(StudioBaseHandler):
 
         user_dict_list = UserInfoModel(manage_context_key).get_dict_list(condition, field="UserID,Account,UserName")
 
-        self.reponse_json_success(user_dict_list)
+        return self.response_json_success(user_dict_list)
 
 
 class SaveRoleHandler(StudioBaseHandler):
@@ -540,23 +540,22 @@ class SaveRoleHandler(StudioBaseHandler):
 
         # 验证数据
         if role_name == "":
-            return self.reponse_common("RoleNameEmpty", "角色名为空")
+            return self.response_common("RoleNameEmpty", "角色名为空")
 
         role_info_model = RoleInfoModel(self.get_manage_context_key())
         role_info = RoleInfo()
         if role_id != "":
             role_info = role_info_model.get_entity_by_id(role_id)
             if not role_info:
-                return self.reponse_common("NoExit", "角色不存在")
+                return self.response_common("NoExit", "角色不存在")
             role_info_c = role_info_model.get_entity("RoleName=%s and RoleID!=%s", params=[role_name, role_id])
             if role_info_c:
-                return self.reponse_common("NoExit", "角色名已存在")
+                return self.response_common("NoExit", "角色名已存在")
         else:
             role_info_c = role_info_model.get_entity("RoleName=%s", params=role_name)
             if role_info_c:
-                return self.reponse_common("NoExit", "角色名已存在")
+                return self.response_common("NoExit", "角色名已存在")
             role_info.RoleID = UUIDHelper.get_uuid()
-            role_info.UserIDNumber = UUIDHelper.get_uuid()
 
         if not self.get_is_super():
             role_info.ChiefUserID = curr_user_id
@@ -570,7 +569,8 @@ class SaveRoleHandler(StudioBaseHandler):
         is_add = role_id == ""
         result = power_model.set_role(role_info, role_user_id_str.split(","), role_menu_id_str.split(","), is_add)
         result.ModifyUser = self.get_curr_user_info().UserName
-        self.reponse_json_success(result.__dict__)
+
+        return self.response_json_success(result.__dict__)
 
 
 class RemoveRoleUserHandler(StudioBaseHandler):
@@ -594,14 +594,14 @@ class RemoveRoleUserHandler(StudioBaseHandler):
         role_id = self.get_param("roleID")
         user_id = self.get_param("userID")
         if role_id == "":
-            return self.reponse_common("EmptyRoleID", "角色ID为空")
+            return self.response_common("EmptyRoleID", "角色ID为空")
         if user_id == "":
-            return self.reponse_common("EmptyUserID", "用户ID为空")
+            return self.response_common("EmptyUserID", "用户ID为空")
 
         power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.remove_role_user(role_id, user_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class DeleteRoleHandler(StudioBaseHandler):
@@ -620,7 +620,7 @@ class DeleteRoleHandler(StudioBaseHandler):
         role_id = self.get_param("RoleID")
 
         if role_id == "":
-            return self.reponse_common("EmptyRoleID", "角色ID为空")
+            return self.response_common("EmptyRoleID", "角色ID为空")
 
         manage_context_key = self.get_manage_context_key()
 
@@ -628,7 +628,7 @@ class DeleteRoleHandler(StudioBaseHandler):
         RolePowerModel(manage_context_key).del_entity("RoleID=%s", role_id)
         RoleInfoModel(manage_context_key).del_entity("RoleID=%s", role_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class DeleteUserHandler(StudioBaseHandler):
@@ -653,17 +653,17 @@ class DeleteUserHandler(StudioBaseHandler):
         is_super = self.get_is_super()
 
         if user_id == "":
-            return self.reponse_common("EmptyUserID", "用户ID为空")
+            return self.response_common("EmptyUserID", "用户ID为空")
 
         if user_id == self.request_user_id():
-            return self.reponse_common("RemoveLimit", "当前账号不能删除")
+            return self.response_common("RemoveLimit", "当前账号不能删除")
 
         power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.remove_user(curr_user_id, user_id)
 
         self.logout(user_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class ModifyUserStatusHandler(StudioBaseHandler):
@@ -688,22 +688,22 @@ class ModifyUserStatusHandler(StudioBaseHandler):
         is_super = self.get_is_super()
 
         if user_id == "":
-            return self.reponse_json_error_params()
+            return self.response_json_error_params()
 
         if is_lock != 0 and is_lock != 1:
-            return self.reponse_json_error_params()
+            return self.response_json_error_params()
 
         user_info_model = UserInfoModel(manage_context_key)
         user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
         if not user_info:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         if not is_super and user_info.ChiefUserID != curr_user_id:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         user_info_model.update_table("IsLock=%s", "UserID=%s", [is_lock, user_id])
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class ResetUserPasswordHandler(StudioBaseHandler):
@@ -728,10 +728,10 @@ class ResetUserPasswordHandler(StudioBaseHandler):
         user_info_model = UserInfoModel(base_manage_context_key)
         user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
         if not user_info:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         if not is_super and user_info.ChiefUserID != curr_user_id:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         sign_password = UserInfoModelEx().sign_password("", user_id)
 
@@ -739,7 +739,7 @@ class ResetUserPasswordHandler(StudioBaseHandler):
 
         self.logout(user_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class ResetUserFaildLoginCountHandler(StudioBaseHandler):
@@ -764,22 +764,22 @@ class ResetUserFaildLoginCountHandler(StudioBaseHandler):
         user_info_model = UserInfoModel(base_manage_context_key)
         user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
         if not user_info:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         if not is_super and user_info.ChiefUserID != curr_user_id:
-            return self.reponse_common("NoExit", "用户不存在")
+            return self.response_common("NoExit", "用户不存在")
 
         user_info_model.update_table("FaildLoginCount=0", "UserID=%s", [user_id])
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class RemoveUserAllRoleHandler(StudioBaseHandler):
     """
     :description: 收回权限
     """
-    # @login_filter(True)
-    # @power_filter(True)
+    @login_filter(True)
+    @power_filter(True)
     @filter_check_params("UserID")
     def get_async(self):
         """
@@ -802,15 +802,15 @@ class RemoveUserAllRoleHandler(StudioBaseHandler):
             if user_info and user_info.ChiefUserID != curr_user_id:
                 role_user_model.del_entity("UserID=%s", user_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class CopyUserRoleHandler(StudioBaseHandler):
     """
     :description: 复制权限
     """
-    # @login_filter(True)
-    # @power_filter(True)
+    @login_filter(True)
+    @power_filter(True)
     @filter_check_params("userID,copyUserID")
     def get_async(self):
         """
@@ -829,4 +829,4 @@ class CopyUserRoleHandler(StudioBaseHandler):
         power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         power_model.copy_user_role(copy_user_id, user_id)
 
-        self.reponse_json_success()
\ No newline at end of file
+        return self.response_json_success()
\ No newline at end of file
