@@ -1,3 +1,11 @@
+# -*- coding: utf-8 -*-
+"""
+:Author: ChenXiaolei
+:Date: 2021-01-06 18:36:26
+:LastEditTime: 2021-01-08 11:33:37
+:LastEditors: ChenXiaolei
+:Description: 操作行为日志模型
+"""
 
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
@@ -19,7 +27,7 @@ class LogAction:
         super(LogAction, self).__init__()
         self.id = 0  # 自增主键
         self.module_code = ""  # 模块名称
-        self.user_id = 0  # 用户id
+        self.user_id = ""  # 用户id
         self.content = ""  # 日志内容
         self.record_time = 0  # 记录时间
         self.client_ip = ""  # 客户端IP
