@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-22 14:32:40
-:LastEditTime: 2022-12-06 18:04:03
+:LastEditTime: 2022-12-07 09:11:59
 :LastEditors: HuangJingCan
 :Description: 栏目扩展类
 """
@@ -442,8 +442,9 @@ class MenuInfoModelEx(MenuInfoModel):
         for menu in menu_list:
             have_child = 1 if self.get_total("ParentID=%s", params=[menu.MenuID]) > 0 else 0
             menu.HaveChild = have_child
-            id_list = menu.IDPath.strip(',').split(',')
-            menu.Depth = len(id_list)
+            menu.Depth = len(menu.IDPath.strip(',').split(','))
+            p_menu = self.get_entity_by_id(menu.ParentID)
+            menu.MenuNamePath = p_menu.MenuNamePath + menu.MenuName + "," if p_menu else menu.MenuNamePath
 
             MenuInfoModelEx(sub_table="copy").add_entity(menu)
 
