@@ -1,9 +1,9 @@
 """
-@Author: HuangJingCan
-@Date: 2020-03-24 19:48:05
-@LastEditTime: 2020-04-15 10:08:00
-@LastEditors: HuangJingCan
-@Description: 角色权限扩展类
+:Author: HuangJingCan
+:Date: 2020-03-24 19:48:05
+:LastEditTime: 2020-04-15 10:08:00
+:LastEditors: HuangJingCan
+:Description: 角色权限扩展类
 """
 from seven_studio.models.db_models.role.role_power_model import *
 
